@@ -68,7 +68,7 @@ class DOMHTMLMaindetailsParser(DOMParserBase):
                             'year': "./a[starts-with(@href, " \
                                     "'/BornInYear?')]/text()"
                             },
-                        postprocess=lambda x: build_date(x)),
+                        postprocess=build_date),
                     Attribute(key='birth notes',
                         path="./a[starts-with(@href, '/BornWhere?')]/text()")]
     _death_attrs = [Attribute(key='death date',
@@ -78,7 +78,7 @@ class DOMHTMLMaindetailsParser(DOMParserBase):
                             'year': "./a[starts-with(@href, " \
                                     "'/DiedInYear?')]/text()"
                             },
-                        postprocess=lambda x: build_date(x)),
+                        postprocess=build_date),
                     Attribute(key='death notes',
                         path="./text()",
                         # TODO: check if this slicing is always correct
@@ -137,6 +137,12 @@ class DOMHTMLMaindetailsParser(DOMParserBase):
                 '</li>'),
             (_reRoles, _manageRoles)]
 
+    def postprocess_data(self, data):
+        for what in 'birth date', 'death date':
+            if what in data and not data[what]:
+                del data[what]
+        return data
+
 
 class DOMHTMLBioParser(DOMParserBase):
     """Parser for the "biography" page of a given person.
@@ -157,7 +163,7 @@ class DOMHTMLBioParser(DOMParserBase):
                             'year': "./a[starts-with(@href, " \
                                     "'/BornInYear?')]/text()"
                             },
-                        postprocess=lambda x: build_date(x)),
+                        postprocess=build_date),
                     Attribute(key='birth notes',
                         path="./a[starts-with(@href, '/BornWhere?')]/text()")]
     _death_attrs = [Attribute(key='death date',
@@ -167,7 +173,7 @@ class DOMHTMLBioParser(DOMParserBase):
                             'year': "./a[starts-with(@href, " \
                                     "'/DiedInYear?')]/text()"
                             },
-                        postprocess=lambda x: build_date(x)),
+                        postprocess=build_date),
                     Attribute(key='death notes',
                         path="./text()",
                         # TODO: check if this slicing is always correct
@@ -216,9 +222,9 @@ class DOMHTMLBioParser(DOMParserBase):
                                 'name': "./td[1]//text()",
                                 'info': "./td[2]//text()"
                                 },
-                            postprocess=lambda x: "%s::%s" % \
-                                            (x.get('name').strip(),
-                                                (x.get('info') or u'').strip()))),
+                            postprocess=lambda x: ("%s::%s" % \
+                                (x.get('name').strip(),
+                                (x.get('info') or u'').strip())).strip(':'))),
             Extractor(label='trade mark',
                         path="//div[h5='Trade Mark']/p",
                         attrs=Attribute(key='trade mark',
@@ -263,6 +269,12 @@ class DOMHTMLBioParser(DOMParserBase):
         (re.compile('\.<br><br>([^\s])', re.I), r'. \1')
         ]
 
+    def postprocess_data(self, data):
+        for what in 'birth date', 'death date':
+            if what in data and not data[what]:
+                del data[what]
+        return data
+
 
 class DOMHTMLOtherWorksParser(DOMParserBase):
     """Parser for the "other works" and "agent" pages of a given person.
@@ -312,7 +324,7 @@ def _build_episode(link, title, minfo, role, roleA, roleAID):
                 slfRole = slfRole[:commidx]
         if slfRole and role is None and roleA is None:
             role = slfRole
-    eps_data = analyze_title(title, canonical=1)
+    eps_data = analyze_title(title)
     eps_data['kind'] = u'episode'
     # FIXME: it's wrong for multiple characters (very rare on tv series?).
     if role is None:
@@ -382,7 +394,7 @@ class DOMHTMLSeriesParser(DOMParserBase):
             link = self.xpath(dom, "//a/@href")[0]
             title = self.xpath(dom, "//a/text()")[0][1:-1]
             series = Movie(movieID=analyze_imdbid(link),
-                           data=analyze_title(title, canonical=1),
+                           data=analyze_title(title),
                            accessSystem=self._as, modFunct=self._modFunct)
             nd[series] = []
             for episode in data[key]:
@@ -457,7 +469,7 @@ class DOMHTMLPersonSalesParser(DOMParserBase):
                             'cover': "./ancestor::td[1]/../" \
                                     "td[1]/a[1]/img[1]/@src",
                             },
-                        postprocess=lambda x: _parse_merchandising_link(x))),
+                        postprocess=_parse_merchandising_link)),
     ]
 
     preprocessors = [
